# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = ['Instance']


class Instance(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_key: Optional[pulumi.Input[str]] = None,
                 disk_category: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[str]] = None,
                 engine_type: Optional[pulumi.Input[str]] = None,
                 instance_alias: Optional[pulumi.Input[str]] = None,
                 instance_class: Optional[pulumi.Input[str]] = None,
                 instance_storage: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Time Series Database (TSDB) Instance resource.

        For information about Time Series Database (TSDB) Instance and how to use it, see [What is Time Series Database (TSDB)](https://www.alibabacloud.com/help/en/doc-detail/55652.htm).

        > **NOTE:** Available in v1.112.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.tsdb.get_zones()
        example_network = alicloud.vpc.Network("exampleNetwork", cidr_block="192.168.0.0/16")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            availability_zone=example_zones.ids[0],
            cidr_block="192.168.1.0/24",
            vpc_id=example_network.id)
        example_instance = alicloud.tsdb.Instance("exampleInstance",
            payment_type="PayAsYouGo",
            vswitch_id=example_switch.id,
            instance_storage="50",
            instance_class="tsdb.1x.basic",
            engine_type="tsdb_tsdb",
            instance_alias="tf-testaccTsdbInstance")
        ```

        ## Import

        TSDB Instance can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:tsdb/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_key: The app key.
        :param pulumi.Input[str] disk_category: The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        :param pulumi.Input[str] duration: The duration.
        :param pulumi.Input[str] engine_type: The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        :param pulumi.Input[str] instance_alias: The alias of the instance.
        :param pulumi.Input[str] instance_class: The specification of the instance. 
               - Following enumerative value for TSDB for InfluxDB️ standart edition:
               - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB for InfluxDB High-availability edition:
               - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB:
               - `tsdb.1x.basic` refers to basic edition I;
               - `tsdb.3x.basic` refers to basic edition II;
               - `tsdb.4x.basic` refers to basic edtion III;
               - `tsdb.12x.standard` refers to standard edition I;
               - `tsdb.24x.standard` refers to standard edition II;
               - `tsdb.48x.large` refers to ultimate edition I;
               - `tsdb.94x.large` refers to ultimate edition II.
        :param pulumi.Input[str] instance_storage: The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        :param pulumi.Input[str] payment_type: The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        :param pulumi.Input[str] vswitch_id: The vswitch id.
        :param pulumi.Input[str] zone_id: The zone ID of the instance.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['app_key'] = app_key
            __props__['disk_category'] = disk_category
            __props__['duration'] = duration
            __props__['engine_type'] = engine_type
            __props__['instance_alias'] = instance_alias
            if instance_class is None and not opts.urn:
                raise TypeError("Missing required property 'instance_class'")
            __props__['instance_class'] = instance_class
            if instance_storage is None and not opts.urn:
                raise TypeError("Missing required property 'instance_storage'")
            __props__['instance_storage'] = instance_storage
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__['payment_type'] = payment_type
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__['vswitch_id'] = vswitch_id
            __props__['zone_id'] = zone_id
            __props__['status'] = None
        super(Instance, __self__).__init__(
            'alicloud:tsdb/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_key: Optional[pulumi.Input[str]] = None,
            disk_category: Optional[pulumi.Input[str]] = None,
            duration: Optional[pulumi.Input[str]] = None,
            engine_type: Optional[pulumi.Input[str]] = None,
            instance_alias: Optional[pulumi.Input[str]] = None,
            instance_class: Optional[pulumi.Input[str]] = None,
            instance_storage: Optional[pulumi.Input[str]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None,
            zone_id: Optional[pulumi.Input[str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_key: The app key.
        :param pulumi.Input[str] disk_category: The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        :param pulumi.Input[str] duration: The duration.
        :param pulumi.Input[str] engine_type: The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        :param pulumi.Input[str] instance_alias: The alias of the instance.
        :param pulumi.Input[str] instance_class: The specification of the instance. 
               - Following enumerative value for TSDB for InfluxDB️ standart edition:
               - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB for InfluxDB High-availability edition:
               - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
               - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
               - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
               - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
               - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
               - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
               - Following enumerative value for TSDB:
               - `tsdb.1x.basic` refers to basic edition I;
               - `tsdb.3x.basic` refers to basic edition II;
               - `tsdb.4x.basic` refers to basic edtion III;
               - `tsdb.12x.standard` refers to standard edition I;
               - `tsdb.24x.standard` refers to standard edition II;
               - `tsdb.48x.large` refers to ultimate edition I;
               - `tsdb.94x.large` refers to ultimate edition II.
        :param pulumi.Input[str] instance_storage: The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        :param pulumi.Input[str] payment_type: The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        :param pulumi.Input[str] status: Instance status, enumerative: `ACTIVATION`, `DELETED`, `CREATING`, `CLASS_CHANGING`, `LOCKED`.
        :param pulumi.Input[str] vswitch_id: The vswitch id.
        :param pulumi.Input[str] zone_id: The zone ID of the instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["app_key"] = app_key
        __props__["disk_category"] = disk_category
        __props__["duration"] = duration
        __props__["engine_type"] = engine_type
        __props__["instance_alias"] = instance_alias
        __props__["instance_class"] = instance_class
        __props__["instance_storage"] = instance_storage
        __props__["payment_type"] = payment_type
        __props__["status"] = status
        __props__["vswitch_id"] = vswitch_id
        __props__["zone_id"] = zone_id
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appKey")
    def app_key(self) -> pulumi.Output[Optional[str]]:
        """
        The app key.
        """
        return pulumi.get(self, "app_key")

    @property
    @pulumi.getter(name="diskCategory")
    def disk_category(self) -> pulumi.Output[Optional[str]]:
        """
        The disk type of instance. Valid when the engine type is `tsdb_influxdb`. `cloud_ssd` refers to SSD disk, `cloud_efficiency` refers to efficiency disk, `cloud_essd` refers to ESSD PL1 disk. Valid values: `cloud_efficiency`, `cloud_essd`, `cloud_ssd`.
        """
        return pulumi.get(self, "disk_category")

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Output[Optional[str]]:
        """
        The duration.
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> pulumi.Output[Optional[str]]:
        """
        The engine type of instance Enumerative: `tsdb_tsdb` refers to TSDB, `tsdb_influxdb` refers to TSDB for InfluxDB️.
        """
        return pulumi.get(self, "engine_type")

    @property
    @pulumi.getter(name="instanceAlias")
    def instance_alias(self) -> pulumi.Output[Optional[str]]:
        """
        The alias of the instance.
        """
        return pulumi.get(self, "instance_alias")

    @property
    @pulumi.getter(name="instanceClass")
    def instance_class(self) -> pulumi.Output[str]:
        """
        The specification of the instance. 
        - Following enumerative value for TSDB for InfluxDB️ standart edition:
        - `influxdata.n1.mxlarge` refers to 2 CPU 8GB memory;
        - `influxdata.n1.xlarge` refers to 4 CPU 16GB memory;
        - `influxdata.n1.2xlarge` refers to 8 CPU 32 GB memory;
        - `influxdata.n1.4xlarge` refers to 16 CPU 64 GB memory;
        - `influxdata.n1.8xlarge` refers to 32 CPU 128 GB memory;
        - `influxdata.n1.16xlarge` refers to 64 CPU 256 GB memory.
        - Following enumerative value for TSDB for InfluxDB High-availability edition:
        - `influxdata.n1.mxlarge_ha` refers to 2 CPU 8GB memory;
        - `influxdata.n1.xlarge_ha` refers to 4 CPU 16GB memory;
        - `influxdata.n1.2xlarge_ha` refers to 8 CPU 32 GB memory;
        - `influxdata.n1.4xlarge_ha` refers to 16 CPU 64 GB memory;
        - `influxdata.n1.8xlarge_ha` refers to 32 CPU 128 GB memory;
        - `influxdata.n1.16xlarge_ha` refers to 64 CPU 256 GB memory.
        - Following enumerative value for TSDB:
        - `tsdb.1x.basic` refers to basic edition I;
        - `tsdb.3x.basic` refers to basic edition II;
        - `tsdb.4x.basic` refers to basic edtion III;
        - `tsdb.12x.standard` refers to standard edition I;
        - `tsdb.24x.standard` refers to standard edition II;
        - `tsdb.48x.large` refers to ultimate edition I;
        - `tsdb.94x.large` refers to ultimate edition II.
        """
        return pulumi.get(self, "instance_class")

    @property
    @pulumi.getter(name="instanceStorage")
    def instance_storage(self) -> pulumi.Output[str]:
        """
        The storage capacity of the instance. Unit: GB. For example, the value 50 indicates 50 GB. Does not support shrink storage.
        """
        return pulumi.get(self, "instance_storage")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The billing method. Valid values: `PayAsYouGo` and `Subscription`. The `PayAsYouGo` value indicates the pay-as-you-go method, and the `Subscription` value indicates the subscription method.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Instance status, enumerative: `ACTIVATION`, `DELETED`, `CREATING`, `CLASS_CHANGING`, `LOCKED`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[str]:
        """
        The vswitch id.
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[str]:
        """
        The zone ID of the instance.
        """
        return pulumi.get(self, "zone_id")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

